import pandas as pd
import matplotlib.pyplot as plt

# these ones are just for fun to get 12 random colors
from matplotlib.colors import get_named_colors_mapping
from random import sample

def read_data(filename):
    data = pd.read_csv(filename, sep=" ",
                       names=['year', 'month', 'day', 'hour', 'sealevel'])

    # subtract one from every hour cause they are 1-24 instead of 0-23
    data['hour'] -= 1

    # use year, month, day and hour to construct datetime object
    data['date'] = pd.to_datetime(data[['year', 'month', 'day', 'hour']])
    data = data.set_index('date')

    return data



def plot_months(dataframe):
    # pick out just sealevel and group by month and hour
    sl = dataframe['sealevel']
    grouped = sl.groupby([sl.index.month, sl.index.hour]).mean()

    # pick 12 random colors
    month_color = sample(get_named_colors_mapping().keys(), 12)

    grouped.unstack(level=0).plot(color=month_color)

    plt.title("Average Sealevel by Month and Time of Day")
    plt.xlabel("Time of Day")
    plt.ylabel("Sealevel (cm)")
    plt.legend(title="Month", ncol=3)
    plt.show()


def plot_rolling_average(dataframe, month=6):
    sl = dataframe['sealevel']
    rolling_avg = sl.rolling('1490min').mean() # 24h50min = one tide cycle

    sl[sl.index.month == month].plot(label='Raw Data', alpha=0.4)
    rolling_avg[rolling_avg.index.month == month].plot(label='Rolling Average (24h50min)')

    plt.ylabel("Sealevel (cm)")
    plt.legend()
    plt.show()



if __name__ == "__main__":
    data = read_data("../VIK_sealevel_2000.txt")

    plot_months(data)
    plot_rolling_average(data)
